@@ -348,10 +348,27 @@ sub _get_desired_caps ( $self, $args ) {
             args => [    #
 
                 # https://bugs.chromium.org/p/chromium/issues/detail?id=721739
-                # headless chrome ignoring --ignore-certificate-errors
-                $args->{proxy} ? ( "--proxy-server=$args->{proxy}", '--ignore-certificate-errors' ) : (),
+                # NOTE headless chrome ignoring --ignore-certificate-errors
+                $args->{proxy} ? ( "--proxy-server=$args->{proxy}", '--ignore-certificate-errors', '--allow-insecure-localhost' ) : (),
 
+                # https://bugs.chromium.org/p/chromedriver/issues/detail?id=878
+                # NOTE remote debuggind not works with chromedriver
+                # '--remote-debugging-address=192.168.175.10',
+                # '--remote-debugging-port=9222',
+
+                '--disable-background-networking',
+                '--disable-client-side-phishing-detection',
+                '--disable-component-update',
+                '--disable-default-apps',
+                '--disable-hang-monitor',
+                '--disable-prompt-on-repost',
+                '--disable-sync',
+                '--disable-web-resources',
+
+                # '--window-size=800x600',
                 '--start-maximized',
+                '--disable-default-apps',
+                '--no-first-run',
                 '--disable-infobars',
                 '--disable-popup-blocking',
                 '--disable-default-apps',
@@ -363,13 +380,12 @@ sub _get_desired_caps ( $self, $args ) {
                 $args->{args} ? $args->{args}->@* : (),
             ],
             binary => $args->{bin} // q[],
+            prefs => {
 
-            #     prefs => {
-            #         ( $self->disable_images ? ( 'profile.default_content_setting_values.images' => 2 ) : () ),
-            #         ( $self->enable_notifications ? () : ( 'profile.default_content_setting_values.notifications' => 2 ) ),
-            #         ( $self->enable_flash         ? () : ( 'profile.default_content_setting_values.plugins'       => 2 ) ),
-            #     },
-            # };
+                #         ( $self->disable_images ? ( 'profile.default_content_setting_values.images' => 2 ) : () ),
+                #         ( $self->enable_notifications ? () : ( 'profile.default_content_setting_values.notifications' => 2 ) ),
+                #         ( $self->enable_flash         ? () : ( 'profile.default_content_setting_values.plugins'       => 2 ) ),
+            }
         };
     }
 
@@ -518,7 +534,7 @@ sub _send_cmd ( $self ) {
 ## |======+======================+================================================================================================================|
 ## |    3 | 1                    | Modules::ProhibitExcessMainComplexity - Main code has high complexity score (22)                               |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 362                  | CodeLayout::ProhibitQuotedWordLists - List of quoted literal words                                             |
+## |    2 | 379                  | CodeLayout::ProhibitQuotedWordLists - List of quoted literal words                                             |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
